/**
 * MainWindow.cpp is part of bmsapp.
 *
 * bmsapp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * bmsapp is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
#include "MainWindow.h"
#include "AboutDialog.h"
#include "InventorySuppliers.h"
#include "InventoryFermentables.h"
#include "InventoryHops.h"
#include "InventoryYeasts.h"
#include "InventoryMiscs.h"
#include "InventoryWaters.h"
#include "InventoryEquipments.h"
#include "ProfileWaters.h"
#include "ProfileMashs.h"
#include "ProfileStyles.h"
#include "ProfileFerments.h"
#include "Setup.h"
#include "PrinterDialog.h"
#include "../ui/ui_MainWindow.h"
#include "config.h"

#include <QApplication>
#include <QCloseEvent>
#include <QDebug>
#include <QStandardItem>
#include <QWidget>
#include <QtWidgets/QTableWidget>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QPushButton>


MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent),  ui(new Ui::MainWindow)
{
    qDebug() << Q_FUNC_INFO;
    ui->setupUi(this);

    setWindowTitle( QString("BMSapp - %1").arg(VERSIONSTRING) );
}


MainWindow::~MainWindow()
{
    qDebug() << Q_FUNC_INFO;
    delete ui;
}


void MainWindow::on_actionExit_triggered()
{
    qDebug() << Q_FUNC_INFO;
    this->close();
}


void MainWindow::fromInventorySuppliers()
{
    qDebug() << Q_FUNC_INFO;
    ui->mainStack->setCurrentIndex(-1);
    ui->mainStack->removeWidget(InventorySuppliersWindow);
    delete InventorySuppliersWindow;
    setWindowTitle( QString("BMSapp - %1").arg(VERSIONSTRING) );
    ui->menuBar->setVisible(true);
}


void MainWindow::on_actionSuppliers_triggered()
{
    qDebug() << Q_FUNC_INFO;

    InventorySuppliersWindow = new InventorySuppliers(this);
    int index = ui->mainStack->count();
    ui->mainStack->addWidget(InventorySuppliersWindow);
    ui->mainStack->setCurrentIndex(index);
    setWindowTitle( QString("BMSapp - %1 - Inventory Suppliers").arg(VERSIONSTRING));
    ui->menuBar->setVisible(false);
}


void MainWindow::fromInventoryFermentables()
{
    qDebug() << Q_FUNC_INFO;
    ui->mainStack->setCurrentIndex(-1);
    ui->mainStack->removeWidget(InventoryFermentablesWindow);
    delete InventoryFermentablesWindow;
    setWindowTitle( QString("BMSapp - %1").arg(VERSIONSTRING) );
    ui->menuBar->setVisible(true);
}


void MainWindow::on_actionFermentables_triggered()
{
    qDebug() << Q_FUNC_INFO;

    InventoryFermentablesWindow = new InventoryFermentables(this);
    int index = ui->mainStack->count();
    ui->mainStack->addWidget(InventoryFermentablesWindow);
    ui->mainStack->setCurrentIndex(index);
    setWindowTitle(QString("BMSapp - %1 - Inventory Fermentables").arg(VERSIONSTRING));
    ui->menuBar->setVisible(false);
}


void MainWindow::fromInventoryHops()
{
    qDebug() << Q_FUNC_INFO;
    delete InventoryHopsWindow;
    this->show();
}


void MainWindow::on_actionHops_triggered()
{
    qDebug() << Q_FUNC_INFO;
    InventoryHopsWindow = new InventoryHops(this);
    QObject::connect(InventoryHopsWindow, SIGNAL(firstWindow()), this, SLOT(fromInventoryHops()));
    this->hide();    // Close the main window
    InventoryHopsWindow->show();  // Show a second window
}


void MainWindow::fromInventoryYeasts()
{
    qDebug() << Q_FUNC_INFO;
    delete InventoryYeastsWindow;
    this->show();
}


void MainWindow::on_actionYeasts_triggered()
{
    qDebug() << Q_FUNC_INFO;
    InventoryYeastsWindow = new InventoryYeasts(this);
    QObject::connect(InventoryYeastsWindow, SIGNAL(firstWindow()), this, SLOT(fromInventoryYeasts()));
    this->hide();    // Close the main window
    InventoryYeastsWindow->show();  // Show a second window
}


void MainWindow::fromInventoryMiscs()
{
    qDebug() << Q_FUNC_INFO;
    delete InventoryMiscsWindow;
    this->show();
}


void MainWindow::on_actionMiscs_triggered()
{
    qDebug() << Q_FUNC_INFO;
    InventoryMiscsWindow = new InventoryMiscs(this);
    QObject::connect(InventoryMiscsWindow, SIGNAL(firstWindow()), this, SLOT(fromInventoryMiscs()));
    this->hide();    // Close the main window
    InventoryMiscsWindow->show();  // Show a second window
}


void MainWindow::fromInventoryWaters()
{
    qDebug() << Q_FUNC_INFO;
    delete InventoryWatersWindow;
    this->show();
}


void MainWindow::on_actionWaters_triggered()
{
    qDebug() << Q_FUNC_INFO;
    InventoryWatersWindow = new InventoryWaters(this);
    QObject::connect(InventoryWatersWindow, SIGNAL(firstWindow()), this, SLOT(fromInventoryWaters()));
    this->hide();    // Close the main window
    InventoryWatersWindow->show();  // Show a second window
}


void MainWindow::fromInventoryEquipments()
{
    qDebug() << Q_FUNC_INFO;
    delete InventoryEquipmentsWindow;
    this->show();
}


void MainWindow::on_actionEquipments_triggered()
{
    qDebug() << Q_FUNC_INFO;
    InventoryEquipmentsWindow = new InventoryEquipments(this);
    QObject::connect(InventoryEquipmentsWindow, SIGNAL(firstWindow()), this, SLOT(fromInventoryEquipments()));
    this->hide();    // Close the main window
    InventoryEquipmentsWindow->show();  // Show a second window
}


void MainWindow::on_actionSupplies_list_triggered()
{
    qDebug() << Q_FUNC_INFO;
    QDialog *printer = new PrinterDialog(PR_SUPPLIES, -1, this);
}


void MainWindow::on_actionYeast_bank_triggered()
{
    qDebug() << Q_FUNC_INFO;
    QDialog *printer = new PrinterDialog(PR_YEASTBANK, -1, this);
}


void MainWindow::fromProfileWaters()
{
    qDebug() << Q_FUNC_INFO;
    delete ProfileWatersWindow;
    this->show();
}


void MainWindow::on_actionWater_profiles_triggered()
{
    qDebug() << Q_FUNC_INFO;
    ProfileWatersWindow = new ProfileWaters(this);
    QObject::connect(ProfileWatersWindow, SIGNAL(firstWindow()), this, SLOT(fromProfileWaters()));
    this->hide();    // Close the main window
    ProfileWatersWindow->show();  // Show a second window
}


void MainWindow::fromProfileMashs()
{
    qDebug() << Q_FUNC_INFO;
    delete ProfileMashsWindow;
    this->show();
}


void MainWindow::on_actionMash_profiles_triggered()
{
    qDebug() << Q_FUNC_INFO;
    ProfileMashsWindow = new ProfileMashs(this);
    QObject::connect(ProfileMashsWindow, SIGNAL(firstWindow()), this, SLOT(fromProfileMashs()));
    this->hide();    // Close the main window
    ProfileMashsWindow->show();  // Show a second window
}


void MainWindow::fromProfileStyles()
{
    qDebug() << Q_FUNC_INFO;
    delete ProfileStylesWindow;
    this->show();
}


void MainWindow::on_actionStyles_profiles_triggered()
{
    qDebug() << Q_FUNC_INFO;
    ProfileStylesWindow = new ProfileStyles(this);
    QObject::connect(ProfileStylesWindow, SIGNAL(firstWindow()), this, SLOT(fromProfileStyles()));
    this->hide();    // Close the main window
    ProfileStylesWindow->show();  // Show a second window
}


void MainWindow::fromProfileFerments()
{
    qDebug() << Q_FUNC_INFO;
    delete ProfileFermentsWindow;
    this->show();
}


void MainWindow::on_actionFerments_profiles_triggered()
{
    qDebug() << Q_FUNC_INFO;
    ProfileFermentsWindow = new ProfileFerments(this);
    QObject::connect(ProfileFermentsWindow, SIGNAL(firstWindow()), this, SLOT(fromProfileFerments()));
    this->hide();    // Close the main window
    ProfileFermentsWindow->show();  // Show a second window
}


void MainWindow::fromSetup()
{
    qDebug() << Q_FUNC_INFO;
    delete SetupWindow;
    this->show();
}


void MainWindow::on_actionSetup_triggered()
{
    qDebug() << Q_FUNC_INFO;
    SetupWindow = new Setup(this);
    QObject::connect(SetupWindow, SIGNAL(firstWindow()), this, SLOT(fromSetup()));
    this->hide();		// Close the main window
    SetupWindow->show();	// Show a setup window
}


void MainWindow::on_actionAbout_triggered()
{
    AboutDialog dialog(this);
    dialog.setModal(true);
    dialog.exec();
}


